==> mmenu-js-8.5.7.tgz: package/README.md <==
mmenu.js
================

The best javascript plugin for app look-alike on- and off-canvas menus with sliding submenus for your website and webapp. It is very customizable through a wide range of options, extensions and add-ons and it will always fit your needs.

Need help? Have a look at [the documentation](https://mmenujs.com) for demos, tutorials, documentation and support.<br />
Working on a WordPress site? Check out [the mmenu WordPress plugin](https://mmenujs.com/wordpress-plugin).

<img src="https://mmenujs.com/img/preview-mmenu.png" alt="mmenu.js" width="100%" />

### Licence
The mmenu javascript plugin is licensed under the [CC-BY-NC-4.0 license](http://creativecommons.org/licenses/by-nc/4.0/).<br />
You can [purchase a license](https://mmenujs.com/download.html) if you want to use it in a commercial project.

### Learn more
+ [Tutorial](https://mmenujs.com/tutorials/off-canvas/)
+ [Options](https://mmenujs.com/documentation/core/options.html)
+ [Extensions](https://mmenujs.com/documentation/extensions/)
+ [Add-ons](https://mmenujs.com/documentation/addons/)
+ [API](https://mmenujs.com/documentation/core/api.html)

### Browser support
As of version 8, the mmenu.js plugin only supports [ECMAScript 6 compliant browsers](https://kangax.github.io/compat-table/es6/).<br />
For Internet Explorer 10 and 11, you''ll need [some polyfills](https://polyfill.io/v3/polyfill.min.js?features=default%2CElement.prototype.matches%2CElement.prototype.prepend%2CElement.prototype.closest).<br />
[Version 7](https://github.com/FrDH/jQuery.mmenu/releases/tag/v7.2.2) should work to some degree in Internet Explorer 9, but you'll need a [matchMedia polyfill](https://polyfill.io/v3/polyfill.min.js?features=default%2CmatchMedia),
[version 6](https://github.com/FrDH/jQuery.mmenu/releases/tag/v6.1.8) should work in Internet Explorer 9 without any shortcomings.</p>

### Development
This project uses [Gulp(4)](http://gulpjs.com/) to compile, minify and concatenate the TS/JS and SCSS/CSS files.
If you are unfamiliar with Gulp, check [this tutorial](https://travismaynard.com/writing/getting-started-with-gulp) on how to get started.<br />
Run `gulp watch` in the command-line to put a watch on the files and run all scripts immediately after saving your changes.

==> mmenu-js-9.0.4.tgz: package/README.md <==
# mmenu.js

The best javascript plugin for app look-alike on- and off-canvas menus with sliding submenus for your website and webapp. It is very customizable through a wide range of options, extensions and add-ons and it will always fit your needs.

Need help? Have a look at [the documentation](https://mmenujs.com) for demos, tutorials, documentation and support.<br />
Working on a WordPress site? Check out [the mmenu WordPress plugin](https://mmenujs.com/wordpress-plugin).

<img src="https://mmenujs.com/img/preview-mmenu.png" alt="mmenu.js" width="100%" />

### Licence

The mmenu javascript plugin is licensed under the [CC-BY-NC-4.0 license](http://creativecommons.org/licenses/by-nc/4.0/).<br />
You can [purchase a license](https://mmenujs.com/download.html) if you want to use it in a commercial project.

### Learn more

-   [Tutorial](https://mmenujs.com/tutorials/off-canvas/)
-   [Options](https://mmenujs.com/documentation/core/options.html)
-   [Extensions](https://mmenujs.com/documentation/extensions/)
-   [Add-ons](https://mmenujs.com/documentation/addons/)
-   [API](https://mmenujs.com/documentation/core/api.html)

### Browser support

As of version 9, the mmenu.js plugin only supports [ECMAScript 6 compliant browsers](https://kangax.github.io/compat-table/es6/).<br />
For Internet Explorer 11, you can use the latest of version 8 and use polyfills where needed.

### Development

This project uses [Gulp(4)](http://gulpjs.com/) to compile, minify and concatenate the TS/JS and SCSS/CSS files.
If you are unfamiliar with Gulp, check [this tutorial](https://travismaynard.com/writing/getting-started-with-gulp) on how to get started.<br />
Run `gulp watch` in the command-line to put a watch on the files and run all scripts immediately after saving your changes.
